@@ -1,4 +1,5 @@
 import json
+import shutil
 import subprocess
 import sys
 from pathlib import Path
@@ -134,6 +135,21 @@ def build(path, name="goldilox", image=None, platform=None):
     click.echo(f"Image {name} created - run with: '{run_command}'")
 
 
+@main.command()
+@click.option('--output', type=str, default=None)
+def dockerfile(output):
+    """Create a Dockerfile for you to work with"""
+    goldilox_path = Path(goldilox.__file__)
+    docker_file_path = str(goldilox_path.parent.absolute().joinpath('app').joinpath('Dockerfile'))
+    docker_output = output or './Dockerfile'
+    shutil.copyfile(docker_file_path, docker_output)
+    with open(docker_output, 'r') as f:
+        click.echo(f.read())
+    click.echo("##################\nDockerfile was writen to './dockerfile'\n")
+    click.echo(
+        "Use 'docker build -f=Dockerfile -t=<image-name> --build-arg PIPELINE_FILE=<pipeline-path> --build-arg PYTHON_IMAGE=<base-image> .' to build a docker image")
+
+
 if __name__ == '__main__':
     args = sys.argv
     if "--help" in args or len(args) == 1:
